#!/usr/bin/python2.7
# -*-coding:Utf-8-*

from netCDF4 import Dataset
import datetime

__author__   = 'Thomas Roc'
__email__    = 'thomas.roc@gmail.co.uk'
__created__  = datetime.datetime(2014, 12, 5)
__modified__ = datetime.datetime(2014, 12, 5)
__version__  = "0.0"
__status__   = "Under Development"

def write_forcing(M, L, tpxo_harmonics, roms_periods, ZAMP, ZPHA, UAMP, UPHA, VAMP, VPHA, MINOR, MAJOR, INCLINATION, PHASE, ncoutFilename='output.nc'):
    """
Create and write in the netcdf forcing file
    """
    print("Creating {} netcdf file".format(ncoutFilename))
    #if os.path.isfile(ncoutFilename):
    #    CREATE_NEW = False
    #else:
    #	CREATE_NEW = True
    SIZE = len(tpxo_harmonics)
    nc = Dataset(ncoutFilename, 'w')
    nc.Description = 'ROMS forcing'
    nc.Author = 'Dr Thomas Roc'
    nc.Created = datetime.datetime.now().isoformat()
    nc.type = 'ROMS FRC file'
    nc.createDimension('xi_rho', L)
    nc.createDimension('eta_rho', M)
    nc.createDimension('tide_period', SIZE)

    nc.createVariable('tide_period', 'f8', 'tide_period')
    nc.variables['tide_period'].units = 'hours'
    nc.variables['tide_period'][:] = roms_periods

    nc.createVariable('tide_Eamp', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Eamp'].units = 'meters'
    nc.variables['tide_Eamp'][:] = ZAMP

    nc.createVariable('tide_Ephase', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Ephase'].units = 'degrees'
    nc.variables['tide_Ephase'][:] = ZPHA 

    nc.createVariable('tide_Uamp', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Uamp'].units = 'meter second-1'
    nc.variables['tide_Uamp'][:] = UAMP

    nc.createVariable('tide_Uphase', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Uphase'].units = 'degrees'
    nc.variables['tide_Uphase'][:] = UPHA
 
    nc.createVariable('tide_Vamp', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Vamp'].units = 'meter second-1'
    nc.variables['tide_Vamp'][:] = VAMP

    nc.createVariable('tide_Vphase', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Vphase'].units = 'degrees'
    nc.variables['tide_Vphase'][:] = VPHA

    nc.createVariable('tide_Cmin', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Cmin'].units = 'meter second-1'
    nc.variables['tide_Cmin'][:] = MINOR

    nc.createVariable('tide_Cmax', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Cmax'].units = 'meter second-1'
    nc.variables['tide_Cmax'][:] = MAJOR

    nc.createVariable('tide_Cangle', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Cangle'].units = 'degrees'
    nc.variables['tide_Cangle'][:] = INCLINATION

    nc.createVariable('tide_Cphase', 'f8', ('tide_period', 'eta_rho', 'xi_rho'))
    nc.variables['tide_Cphase'].units = 'degrees'
    nc.variables['tide_Cphase'][:] = PHASE

